@@ -1,6 +1,9 @@
-# $Id: reorder.R,v 1.3 2003/04/22 15:42:33 warnes Exp $
+# $Id: reorder.R,v 1.4 2004/01/21 12:06:26 warnes Exp $
 #
 # $Log: reorder.R,v $
+# Revision 1.4  2004/01/21 12:06:26  warnes
+# - Add ... argument to match generic provided in mva.
+#
 # Revision 1.3  2003/04/22 15:42:33  warnes
 #
 # - The mva package (which is part of recommended) now provides a
@@ -21,7 +24,7 @@
 
 # Reorder the levels of a factor.
 
-reorder.factor <- function( x, order )
+reorder.factor <- function( x, order, ... )
   {
     if(is.numeric(order))
       factor( x, levels=levels(x)[order] )
